==> qtjambi-designer-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiDesigner/QAbstractFormBuilder_shell.h <==
#ifndef QABSTRACTFORMBUILDER_SHELL_H
#define QABSTRACTFORMBUILDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/abstractformbuilder.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QVariant>
#include <QtCore/qdir.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtDesigner/5.15.2/QtDesigner/private/ui4_p.h>
#include <QtGui/qicon.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qactiongroup.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QAbstractFormBuilder_shell : public QAbstractFormBuilder, public QtJambiShellInterface
{
public:
    QAbstractFormBuilder_shell();
    ~QAbstractFormBuilder_shell() override;

    void addMenuAction(QAction* action0) override;
    bool checkProperty(QObject* obj0, const QString& prop1) const override;
    QAction* createAction(QObject* parent0, const QString& name1) override;
    QActionGroup* createActionGroup(QObject* parent0, const QString& name1) override;
    QLayout* createLayout(const QString& layoutName0, QObject* parent1, const QString& name2) override;
    QWidget* createWidget(const QString& widgetName0, QWidget* parentWidget1, const QString& name2) override;
    QWidget* load(QIODevice* dev0, QWidget* parentWidget1) override;
    void save(QIODevice* dev0, QWidget* widget1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFormBuilder_access : public QAbstractFormBuilder
{
    jboolean __qt_applyPropertyInternally_QObject_ptr_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID o0, jstring propertyName1, jobject value2);
    jobject __qt_iconPaths_cref_QIcon_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jobject __qt_pixmapPaths_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static jobject __qt_toolBarAreaMetaEnum(JNIEnv *__jni_env);
    void __qt_addMenuAction_QAction_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID action0);
    jboolean __qt_checkProperty_QObject_ptr_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID obj0, jstring prop1) const;
    jobject __qt_createAction_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createActionGroup_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createLayout_cref_QString_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring layoutName0, QtJambiNativeID parent1, jstring name2);
    jobject __qt_createWidget_cref_QString_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring widgetName0, QtJambiNativeID parentWidget1, jstring name2);
    jobject __qt_load_QIODevice_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID dev0, QtJambiNativeID parentWidget1);
    void __qt_save_QIODevice_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID dev0, QtJambiNativeID widget1);
};

#endif // QABSTRACTFORMBUILDER_SHELL_H

==> qtjambi-designer-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDesigner/QAbstractFormBuilder_shell.h <==
#ifndef QABSTRACTFORMBUILDER_SHELL_H
#define QABSTRACTFORMBUILDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractformbuilder.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QVariant>
#include <QtCore/qdir.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtGui/qicon.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qactiongroup.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QAbstractFormBuilder_shell : public QAbstractFormBuilder, public QtJambiShellInterface
{
public:
    QAbstractFormBuilder_shell();
    ~QAbstractFormBuilder_shell() override;

    void addMenuAction(QAction* action0) override;
    bool checkProperty(QObject* obj0, const QString& prop1) const override;
    QAction* createAction(QObject* parent0, const QString& name1) override;
    QActionGroup* createActionGroup(QObject* parent0, const QString& name1) override;
    QLayout* createLayout(const QString& layoutName0, QObject* parent1, const QString& name2) override;
    QWidget* createWidget(const QString& widgetName0, QWidget* parentWidget1, const QString& name2) override;
    QWidget* load(QIODevice* dev0, QWidget* parentWidget1) override;
    void save(QIODevice* dev0, QWidget* widget1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFormBuilder_access : public QAbstractFormBuilder
{
    jboolean __qt_applyPropertyInternally_QObject_ptr_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID o0, jstring propertyName1, jobject value2);
    jobject __qt_iconPaths_cref_QIcon_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jobject __qt_pixmapPaths_cref_QPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static jobject __qt_toolBarAreaMetaEnum(JNIEnv *__jni_env);
    void __qt_addMenuAction_QAction_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID action0);
    jboolean __qt_checkProperty_QObject_ptr_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID obj0, jstring prop1) const;
    jobject __qt_createAction_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createActionGroup_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createLayout_cref_QString_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring layoutName0, QtJambiNativeID parent1, jstring name2);
    jobject __qt_createWidget_cref_QString_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring widgetName0, QtJambiNativeID parentWidget1, jstring name2);
    jobject __qt_load_QIODevice_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID dev0, QtJambiNativeID parentWidget1);
    void __qt_save_QIODevice_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID dev0, QtJambiNativeID widget1);
};

#endif // QABSTRACTFORMBUILDER_SHELL_H
